==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerBindingSpecFluentImpl<A extends TriggerBindingSpecFluent<A>> extends BaseFluent<A> implements TriggerBindingSpecFluent<A>{
  public TriggerBindingSpecFluentImpl() {
  }
  public TriggerBindingSpecFluentImpl(TriggerBindingSpec instance) {
    this.withParams(instance.getParams()); 
  }
  private ArrayList<ParamBuilder> params = new ArrayList<ParamBuilder>();
  public A addToParams(Integer index,Param item) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").add(index >= 0 ? index : _visitables.get("params").size(), builder);this.params.add(index >= 0 ? index : params.size(), builder); return (A)this;
  }
  public A setToParams(Integer index,Param item) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    ParamBuilder builder = new ParamBuilder(item);
    if (index < 0 || index >= _visitables.get("params").size()) { _visitables.get("params").add(builder); } else { _visitables.get("params").set(index, builder);}
    if (index < 0 || index >= params.size()) { params.add(builder); } else { params.set(index, builder);}
     return (A)this;
  }
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.Param... items) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").add(builder);this.params.add(builder);} return (A)this;
  }
  public A addAllToParams(Collection<Param> items) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").add(builder);this.params.add(builder);} return (A)this;
  }
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.Param... items) {
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").remove(builder);if (this.params != null) {this.params.remove(builder);}} return (A)this;
  }
  public A removeAllFromParams(Collection<Param> items) {
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").remove(builder);if (this.params != null) {this.params.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromParams(Predicate<ParamBuilder> predicate) {
    if (params == null) return (A) this;
    final Iterator<ParamBuilder> each = params.iterator();
    final List visitables = _visitables.get("params");
    while (each.hasNext()) {
      ParamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Param> getParams() {
    return params != null ? build(params) : null;
  }
  public List<Param> buildParams() {
    return params != null ? build(params) : null;
  }
  public Param buildParam(Integer index) {
    return this.params.get(index).build();
  }
  public Param buildFirstParam() {
    return this.params.get(0).build();
  }
  public Param buildLastParam() {
    return this.params.get(params.size() - 1).build();
  }
  public Param buildMatchingParam(Predicate<ParamBuilder> predicate) {
    for (ParamBuilder item: params) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingParam(Predicate<ParamBuilder> predicate) {
    for (ParamBuilder item: params) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withParams(List<Param> params) {
    if (this.params != null) { _visitables.get("params").removeAll(this.params);}
    if (params != null) {this.params = new ArrayList(); for (Param item : params){this.addToParams(item);}} else { this.params = null;} return (A) this;
  }
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.Param... params) {
    if (this.params != null) {this.params.clear();}
    if (params != null) {for (Param item :params){ this.addToParams(item);}} return (A) this;
  }
  public Boolean hasParams() {
    return params != null && !params.isEmpty();
  }
  public A addNewParam(String name,String value) {
    return (A)addToParams(new Param(name, value));
  }
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParam() {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl();
  }
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParamLike(Param item) {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl(-1, item);
  }
  public TriggerBindingSpecFluent.ParamsNested<A> setNewParamLike(Integer index,Param item) {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl(index, item);
  }
  public TriggerBindingSpecFluent.ParamsNested<A> editParam(Integer index) {
    if (params.size() <= index) throw new RuntimeException("Can't edit params. Index exceeds size.");
    return setNewParamLike(index, buildParam(index));
  }
  public TriggerBindingSpecFluent.ParamsNested<A> editFirstParam() {
    if (params.size() == 0) throw new RuntimeException("Can't edit first params. The list is empty.");
    return setNewParamLike(0, buildParam(0));
  }
  public TriggerBindingSpecFluent.ParamsNested<A> editLastParam() {
    int index = params.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last params. The list is empty.");
    return setNewParamLike(index, buildParam(index));
  }
  public TriggerBindingSpecFluent.ParamsNested<A> editMatchingParam(Predicate<ParamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<params.size();i++) { 
    if (predicate.test(params.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching params. No match found.");
    return setNewParamLike(index, buildParam(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerBindingSpecFluentImpl that = (TriggerBindingSpecFluentImpl) o;
    if (params != null ? !params.equals(that.params) :that.params != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(params,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (params != null && !params.isEmpty()) { sb.append("params:"); sb.append(params); }
    sb.append("}");
    return sb.toString();
  }
  class ParamsNestedImpl<N> extends ParamFluentImpl<TriggerBindingSpecFluent.ParamsNested<N>> implements TriggerBindingSpecFluent.ParamsNested<N>,Nested<N>{
    ParamsNestedImpl(Integer index,Param item) {
      this.index = index;
      this.builder = new ParamBuilder(this, item);
    }
    ParamsNestedImpl() {
      this.index = -1;
      this.builder = new ParamBuilder(this);
    }
    ParamBuilder builder;
    Integer index;
    public N and() {
      return (N) TriggerBindingSpecFluentImpl.this.setToParams(index,builder.build());
    }
    public N endParam() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerBindingSpecFluentImpl<A extends TriggerBindingSpecFluent<A>> extends BaseFluent<A> implements TriggerBindingSpecFluent<A>{
  public TriggerBindingSpecFluentImpl() {
  }
  public TriggerBindingSpecFluentImpl(TriggerBindingSpec instance) {
    if (instance != null) {
      this.withParams(instance.getParams());
    }
  }
  private ArrayList<ParamBuilder> params = new ArrayList<ParamBuilder>();
  public A addToParams(int index,Param item) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    ParamBuilder builder = new ParamBuilder(item);
    if (index < 0 || index >= params.size()) { _visitables.get("params").add(builder); params.add(builder); } else { _visitables.get("params").add(index, builder); params.add(index, builder);}
    return (A)this;
  }
  public A setToParams(int index,Param item) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    ParamBuilder builder = new ParamBuilder(item);
    if (index < 0 || index >= params.size()) { _visitables.get("params").add(builder); params.add(builder); } else { _visitables.get("params").set(index, builder); params.set(index, builder);}
    return (A)this;
  }
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.Param... items) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").add(builder);this.params.add(builder);} return (A)this;
  }
  public A addAllToParams(Collection<Param> items) {
    if (this.params == null) {this.params = new ArrayList<ParamBuilder>();}
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").add(builder);this.params.add(builder);} return (A)this;
  }
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.Param... items) {
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").remove(builder);if (this.params != null) {this.params.remove(builder);}} return (A)this;
  }
  public A removeAllFromParams(Collection<Param> items) {
    for (Param item : items) {ParamBuilder builder = new ParamBuilder(item);_visitables.get("params").remove(builder);if (this.params != null) {this.params.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromParams(Predicate<ParamBuilder> predicate) {
    if (params == null) return (A) this;
    final Iterator<ParamBuilder> each = params.iterator();
    final List visitables = _visitables.get("params");
    while (each.hasNext()) {
      ParamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Param> getParams() {
    return params != null ? build(params) : null;
  }
  public List<Param> buildParams() {
    return params != null ? build(params) : null;
  }
  public Param buildParam(int index) {
    return this.params.get(index).build();
  }
  public Param buildFirstParam() {
    return this.params.get(0).build();
  }
  public Param buildLastParam() {
    return this.params.get(params.size() - 1).build();
  }
  public Param buildMatchingParam(Predicate<ParamBuilder> predicate) {
    for (ParamBuilder item: params) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingParam(Predicate<ParamBuilder> predicate) {
    for (ParamBuilder item: params) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withParams(List<Param> params) {
    if (this.params != null) { _visitables.get("params").clear();}
    if (params != null) {this.params = new ArrayList(); for (Param item : params){this.addToParams(item);}} else { this.params = null;} return (A) this;
  }
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.Param... params) {
    if (this.params != null) {this.params.clear(); _visitables.remove("params"); }
    if (params != null) {for (Param item :params){ this.addToParams(item);}} return (A) this;
  }
  public Boolean hasParams() {
    return params != null && !params.isEmpty();
  }
  public A addNewParam(String name,String value) {
    return (A)addToParams(new Param(name, value));
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> addNewParam() {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl();
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> addNewParamLike(Param item) {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl(-1, item);
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> setNewParamLike(int index,Param item) {
    return new TriggerBindingSpecFluentImpl.ParamsNestedImpl(index, item);
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> editParam(int index) {
    if (params.size() <= index) throw new RuntimeException("Can't edit params. Index exceeds size.");
    return setNewParamLike(index, buildParam(index));
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> editFirstParam() {
    if (params.size() == 0) throw new RuntimeException("Can't edit first params. The list is empty.");
    return setNewParamLike(0, buildParam(0));
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> editLastParam() {
    int index = params.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last params. The list is empty.");
    return setNewParamLike(index, buildParam(index));
  }
  public TriggerBindingSpecFluentImpl.ParamsNested<A> editMatchingParam(Predicate<ParamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<params.size();i++) { 
    if (predicate.test(params.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching params. No match found.");
    return setNewParamLike(index, buildParam(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerBindingSpecFluentImpl that = (TriggerBindingSpecFluentImpl) o;
    if (!java.util.Objects.equals(params, that.params)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(params,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (params != null) { sb.append("params:"); sb.append(params); }
    sb.append("}");
    return sb.toString();
  }
  class ParamsNestedImpl<N> extends ParamFluentImpl<TriggerBindingSpecFluentImpl.ParamsNested<N>> implements TriggerBindingSpecFluentImpl.ParamsNested<N>,Nested<N>{
    ParamsNestedImpl(int index,Param item) {
      this.index = index;
      this.builder = new ParamBuilder(this, item);
    }
    ParamsNestedImpl() {
      this.index = -1;
      this.builder = new ParamBuilder(this);
    }
    ParamBuilder builder;
    int index;
    public N and() {
      return (N) TriggerBindingSpecFluentImpl.this.setToParams(index,builder.build());
    }
    public N endParam() {
      return and();
    }
    
  }
  
}
